<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//pt_PT

$LANG=array();


$LANG['backup'][0]="Proteção de uma base SQL"; 
$LANG['backup'][1]="Proteção de uma base XML"; 
$LANG['backup'][11]="Tamanho"; 
$LANG['backup'][13]="Visualizar/Descarregar"; 
$LANG['backup'][16]="Replace the current database with the backup file:"; 
$LANG['backup'][17]="Delete this file"; 
$LANG['backup'][18]="Backup the database"; 
$LANG['backup'][19]="Agora"; 
$LANG['backup'][21]="Este ficheiro já existe"; 
$LANG['backup'][22]="Incapaz de encontrar o byte"; 
$LANG['backup'][23]="Erro Mysql, início em"; 
$LANG['backup'][24]="Redireccionamento automático, caso contrário pressione"; 

$LANG['bookmark'][1]="marcador"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Não tem marcadores guardados"; 
$LANG['bookmark'][4]="Novo marcador"; 
$LANG['bookmark'][5]="Marcadores Públicos"; 
$LANG['bookmark'][6]="Aplicar por padrão"; 

$LANG['buttons'][0]="Pesquisar"; 
$LANG['buttons'][2]="Publicar"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Instalar"; 
$LANG['buttons'][5]="Remover"; 
$LANG['buttons'][6]="Eliminar"; 
$LANG['buttons'][7]="Actualizar"; 
$LANG['buttons'][8]="Adicionar"; 
$LANG['buttons'][9]="Conectar"; 
$LANG['buttons'][10]="Desconectar"; 
$LANG['buttons'][11]="Próximo"; 
$LANG['buttons'][12]="Anterior"; 
$LANG['buttons'][13]="Voltar"; 
$LANG['buttons'][14]="Modificar"; 
$LANG['buttons'][15]="Programação"; 
$LANG['buttons'][16]="Espaço em branco"; 
$LANG['buttons'][17]="Invert the selection"; 
$LANG['buttons'][18]="Verificar todos"; 
$LANG['buttons'][19]="Desactivar selecção"; 
$LANG['buttons'][20]="Mover"; 
$LANG['buttons'][21]="Restaurar"; 
$LANG['buttons'][22]="Remoção"; 
$LANG['buttons'][23]="Mostrar"; 
$LANG['buttons'][24]="Subir"; 
$LANG['buttons'][25]="Descer"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Exportar"; 
$LANG['buttons'][32]="Fim"; 
$LANG['buttons'][33]="Inicio"; 
$LANG['buttons'][34]="Cancelar"; 
$LANG['buttons'][37]="Importar"; 
$LANG['buttons'][38]="Desbloquear"; 
$LANG['buttons'][39]="Substituir"; 
$LANG['buttons'][40]="Mostrar todos"; 
$LANG['buttons'][41]="Activar"; 
$LANG['buttons'][42]="Desactivar"; 
$LANG['buttons'][43]="Navegar"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Antes"; 
$LANG['buttons'][47]="Depois"; 
$LANG['buttons'][48]="Transferir"; 
$LANG['buttons'][49]="Preservar"; 
$LANG['buttons'][50]="Testar"; 
$LANG['buttons'][51]="Guardar"; 
$LANG['buttons'][52]="Carregar"; 
$LANG['buttons'][53]="Limpar"; 
$LANG['buttons'][55]="First"; 
$LANG['buttons'][56]="Last"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Update"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="D"; 
$LANG['calendarD'][1]="S"; 
$LANG['calendarD'][2]="T"; 
$LANG['calendarD'][3]="Q"; 
$LANG['calendarD'][4]="Q"; 
$LANG['calendarD'][5]="S"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Domingo"; 
$LANG['calendarDay'][1]="Segunda-feira"; 
$LANG['calendarDay'][2]="Terça-feira"; 
$LANG['calendarDay'][3]="Quarta-feira"; 
$LANG['calendarDay'][4]="Quinta-feira"; 
$LANG['calendarDay'][5]="Sexta-feira"; 
$LANG['calendarDay'][6]="Sábado"; 

$LANG['calendarM'][0]="Janeiro"; 
$LANG['calendarM'][1]="Fevereiro"; 
$LANG['calendarM'][2]="Março"; 
$LANG['calendarM'][3]="Abril"; 
$LANG['calendarM'][4]="Maio"; 
$LANG['calendarM'][5]="Junho"; 
$LANG['calendarM'][6]="Julho"; 
$LANG['calendarM'][7]="Agosto"; 
$LANG['calendarM'][8]="Setembro"; 
$LANG['calendarM'][9]="Outubro"; 
$LANG['calendarM'][10]="Novembro"; 
$LANG['calendarM'][11]="Dezembro"; 

$LANG['cartridges'][0]="Cartucho"; 
$LANG['cartridges'][7]="Nenhum cartucho encontrado"; 
$LANG['cartridges'][9]="Sem Cartucho"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Tipo de Cartucho"; 
$LANG['cartridges'][13]="Novo"; 
$LANG['cartridges'][14]="Usado"; 
$LANG['cartridges'][15]="Worn"; 
$LANG['cartridges'][16]="Cartucho(s)"; 
$LANG['cartridges'][20]="Novo"; 
$LANG['cartridges'][21]="Usados"; 
$LANG['cartridges'][22]="Worn"; 
$LANG['cartridges'][24]="Adicionar data"; 
$LANG['cartridges'][27]="Ligado"; 
$LANG['cartridges'][29]="Fim de Vida"; 
$LANG['cartridges'][32]="Tipo de impressoras compatíveis"; 
$LANG['cartridges'][33]="Cartuchos Usados"; 
$LANG['cartridges'][34]="Nenhum Cartucho Livre"; 
$LANG['cartridges'][35]="Used cartridges"; 
$LANG['cartridges'][37]="Fita"; 
$LANG['cartridges'][39]="Contador da impressora"; 
$LANG['cartridges'][40]="Tempo em armazém"; 
$LANG['cartridges'][41]="Tempo em uso"; 
$LANG['cartridges'][42]="Número de páginas impressas"; 

$LANG['central'][2]="Último"; 
$LANG['central'][4]="Nenhum Evento"; 
$LANG['central'][5]="Início"; 
$LANG['central'][6]="Sair"; 
$LANG['central'][7]="Ajuda"; 
$LANG['central'][8]="Adições"; 
$LANG['central'][9]="Os seus tickets em progresso"; 
$LANG['central'][10]="Tickets novos"; 
$LANG['central'][12]="Vista Pessoal"; 
$LANG['central'][13]="Vista Global"; 
$LANG['central'][14]="Vista de grupo"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Não"; 
$LANG['choice'][1]="Sim"; 

$LANG['common'][0]="Sem Nome"; 
$LANG['common'][1]="Artigo"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Fabricante"; 
$LANG['common'][6]="Nome Padrão"; 
$LANG['common'][7]="Escolha um modelo"; 
$LANG['common'][8]="Gerir modelos..."; 
$LANG['common'][9]="Adicionar modelo..."; 
$LANG['common'][10]="Técnico responsável"; 
$LANG['common'][11]="Vista limitada"; 
$LANG['common'][12]="Configuração"; 
$LANG['common'][13]="Modelo padrão"; 
$LANG['common'][14]="Modelos padrão"; 
$LANG['common'][15]="Localização"; 
$LANG['common'][16]="Nome"; 
$LANG['common'][17]="Tipo"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Número de série"; 
$LANG['common'][20]="Número de inventário"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Modelo"; 
$LANG['common'][23]="Operação realizada com sucesso"; 
$LANG['common'][24]="Não existem elementos seleccionados ou operação mal definida"; 
$LANG['common'][25]="Comentários"; 
$LANG['common'][26]="Última actualização"; 
$LANG['common'][27]="Data"; 
$LANG['common'][28]="Eliminado"; 
$LANG['common'][29]="Plugins"; 
$LANG['common'][30]="Novo Artigo"; 
$LANG['common'][31]="Modelo em branco"; 
$LANG['common'][32]="Características"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="Utilizador"; 
$LANG['common'][35]="Grupo"; 
$LANG['common'][36]="Categoria"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Duplicar os elementos o mesmo número de vezes quantas as conexões."; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Alarmes de Email"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Primeiro Nome"; 
$LANG['common'][44]="Default value(s)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Progresso"; 
$LANG['common'][48]="Sobrenome"; 
$LANG['common'][49]="Nenhum"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Nome Completo"; 
$LANG['common'][52]="Servidor"; 
$LANG['common'][53]="Lista"; 
$LANG['common'][54]="Item não encontrado"; 
$LANG['common'][55]="Tem a certeza que quer eliminar este elemento?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Título"; 
$LANG['common'][58]="Valor máximo"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Activo"; 
$LANG['common'][61]="Erro desconhecido"; 
$LANG['common'][62]="Outro"; 
$LANG['common'][63]="Erro(s)"; 
$LANG['common'][64]="Gestor"; 
$LANG['common'][65]="Interface"; 
$LANG['common'][66]="Todos"; 
$LANG['common'][67]="Outros"; 
$LANG['common'][68]="Horizontal"; 
$LANG['common'][69]="Vertical"; 
$LANG['common'][70]="Item adicionado com sucesso"; 
$LANG['common'][71]="Item actualizado com sucesso"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Item restaurado com sucesso"; 
$LANG['common'][75]="Sem permissão para colocar este item em modo recursivo neste entidade"; 
$LANG['common'][76]="Público"; 
$LANG['common'][77]="Privado"; 
$LANG['common'][78]="Definir público"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Carregando..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Flag change forbidden. Linked items found."; 
$LANG['common'][85]="Alterar visibilidade das sub-entidades"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="New card"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Free percentage"; 
$LANG['computers'][2]="Espaço livre"; 
$LANG['computers'][3]="Tamanho global"; 
$LANG['computers'][4]="Sistema de Arquivo"; 
$LANG['computers'][5]="Ponto de montagem"; 
$LANG['computers'][6]="Partição"; 
$LANG['computers'][7]="Adicionar volume"; 
$LANG['computers'][8]="Volumes"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Incluído"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Sem monitor ligado"; 
$LANG['computers'][38]="Sem impressora ligado"; 
$LANG['computers'][39]="Impressoras"; 
$LANG['computers'][40]="Monitor(es)"; 
$LANG['computers'][46]="Periférico(s)"; 
$LANG['computers'][47]="Nenhum dispositivo ligado"; 
$LANG['computers'][48]="Actualização da posição. Os artigos ligados foram movidos na mesma posição."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Utilizador ou Grupo Actualizado. Os artigos conectados foram movidos com os mesmos valores."; 
$LANG['computers'][51]="Actualização da fonte"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Não tem telefone ligado"; 
$LANG['computers'][55]="Telefone(s)"; 
$LANG['computers'][56]="Estado actualizado. Os items ligados foram actualidados usando este estado."; 

$LANG['connect'][0]="Ligações directas"; 
$LANG['connect'][1]="Não ligado"; 
$LANG['connect'][15]="Actualizações automáticas para os seguintes items"; 
$LANG['connect'][16]="Atenção!! Os seguintes items de dois equipamentos não correspondem"; 

$LANG['consumables'][0]="Consumiveis"; 
$LANG['consumables'][1]="Em armazém"; 
$LANG['consumables'][2]="Referência"; 
$LANG['consumables'][7]="Nenhum consumivel encontrado"; 
$LANG['consumables'][9]="Sem consumiveis"; 
$LANG['consumables'][12]="Tipo de Consumível"; 
$LANG['consumables'][13]="Novo"; 
$LANG['consumables'][15]="Usado"; 
$LANG['consumables'][16]="Consumivel"; 
$LANG['consumables'][20]="Novo"; 
$LANG['consumables'][22]="Usado"; 
$LANG['consumables'][23]="Estado"; 
$LANG['consumables'][26]="Data de uso"; 
$LANG['consumables'][32]="Dar"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Localização no armazém"; 
$LANG['consumables'][37]="Voltar ao armazém"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Adicionar um novo componente"; 
$LANG['devices'][1]="Disco rígido"; 
$LANG['devices'][2]="Placa de vídeo"; 
$LANG['devices'][3]="Placa de rede"; 
$LANG['devices'][4]="Processador"; 
$LANG['devices'][5]="Placa Mãe"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Placa de Som"; 
$LANG['devices'][19]="Drives"; 
$LANG['devices'][20]="Controladores"; 
$LANG['devices'][21]="Outros Componentes"; 
$LANG['devices'][22]="Caixas"; 
$LANG['devices'][23]="Fonte de Alimentação"; 
$LANG['devices'][24]="por omissão"; 
$LANG['devices'][25]="Adicionar um componente"; 
$LANG['devices'][26]="Eliminar um componente"; 

$LANG['device_case'][0]="Tamanho"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Escrita"; 
$LANG['device_drive'][1]="Velocidade"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Capacidade"; 

$LANG['device_iface'][0]="Fluxo"; 
$LANG['device_iface'][2]="Endereço MAC"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Energia"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frequência"; 
$LANG['device_ram'][2]="Tamanho"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Arquivo"; 
$LANG['document'][3]="Título"; 
$LANG['document'][4]="Tipo MIME"; 
$LANG['document'][7]="Tipo de documento"; 
$LANG['document'][9]="Extenção"; 
$LANG['document'][10]="Ícone"; 
$LANG['document'][11]="Download autorizado"; 
$LANG['document'][15]="Download"; 
$LANG['document'][16]="Adicionar um Documento"; 
$LANG['document'][18]="Documento"; 
$LANG['document'][19]="Artigos associados"; 
$LANG['document'][21]="Documento associado"; 
$LANG['document'][22]="Ficheiro actual"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="O ficheiro foi eliminado com sucesso"; 
$LANG['document'][25]="Falha ao eliminar o ficheiro"; 
$LANG['document'][26]="O ficheiro é válido. Carregamento foi bem sucedido."; 
$LANG['document'][27]="Potencial ataque no carregamento. Ou, ficheiro demasiado grande. Mudança do ficheiro temporário falhou."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Falha ao criar o directório"; 
$LANG['document'][30]="Verifique se tem as premissões correctas"; 
$LANG['document'][31]="Directório para este documento não existe"; 
$LANG['document'][32]="Tipo de ficheiro sem permissão"; 
$LANG['document'][33]="Endereço de Internet"; 
$LANG['document'][34]="Criar o directório"; 
$LANG['document'][35]="Directório para carregamento não existe"; 
$LANG['document'][36]="Utilize o ficheiro FTP instalado"; 
$LANG['document'][37]="Ficheiro indisponível"; 
$LANG['document'][38]="Ficheiro não encontrado"; 
$LANG['document'][39]="Documento movido com sucesso"; 
$LANG['document'][40]="Movimentação do ficheiro falhou"; 
$LANG['document'][41]="Cópia do documento realizado com sucesso"; 
$LANG['document'][42]="Adicionado por"; 
$LANG['document'][43]="Ficheiro desconhecido"; 
$LANG['document'][44]="Nome de ficheiro inválido"; 
$LANG['document'][45]="Acesso não autorizado a este ficheiro"; 
$LANG['document'][46]="Falha no envio do ficheiro (provavelmente por causa do seu tamanho)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Entidade"; 
$LANG['entity'][2]="Entidade de raiz"; 
$LANG['entity'][3]="Associar a uma entidade"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Atribução automática de utilizador"; 
$LANG['entity'][7]="estrutura de árvore"; 
$LANG['entity'][8]="Por entidade"; 
$LANG['entity'][9]="Entidades filho"; 
$LANG['entity'][10]="Escolha a entidade pretendida"; 
$LANG['entity'][11]="para ver a entidade e suas subentidades"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Serviço"; 
$LANG['event'][3]="Nível"; 
$LANG['event'][4]="Mensagem"; 
$LANG['event'][18]="Campo"; 
$LANG['event'][19]="Actualização"; 
$LANG['event'][20]="Sem histórico"; 

$LANG['financial'][1]="Contrato"; 
$LANG['financial'][2]="Tem vida"; 
$LANG['financial'][3]="Informações comerciais"; 
$LANG['financial'][4]="Número"; 
$LANG['financial'][5]="Custo"; 
$LANG['financial'][6]="Tipo de Contrato"; 
$LANG['financial'][8]="Duração"; 
$LANG['financial'][9]="Ano(s)"; 
$LANG['financial'][10]="Notice"; 
$LANG['financial'][11]="Periocidade da factura"; 
$LANG['financial'][13]="Número da conta ( NIB )"; 
$LANG['financial'][14]="Data de compra"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Informação da garantia"; 
$LANG['financial'][18]="Número de ordem"; 
$LANG['financial'][19]="Formulário de entrega"; 
$LANG['financial'][20]="Número de imobilização"; 
$LANG['financial'][21]="Valor"; 
$LANG['financial'][22]="Tipo de amortização"; 
$LANG['financial'][23]="Duração de amortização"; 
$LANG['financial'][24]="Adicionar contacto"; 
$LANG['financial'][25]="Adicionar Fornecedor"; 
$LANG['financial'][26]="Fornecedor"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Adicionar um Contacto"; 
$LANG['financial'][36]="Adicionar um Contrato"; 
$LANG['financial'][42]="Comercial"; 
$LANG['financial'][43]="Técnico"; 
$LANG['financial'][44]="Endereço"; 
$LANG['financial'][45]="Endereço na internet"; 
$LANG['financial'][46]="Contactos Associados"; 
$LANG['financial'][47]="Linear"; 
$LANG['financial'][48]="Degressivo"; 
$LANG['financial'][50]="Emprestimo"; 
$LANG['financial'][51]="Aluguer"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Seguro"; 
$LANG['financial'][54]="Assistência de componentes físicos"; 
$LANG['financial'][55]="Assistência de programas"; 
$LANG['financial'][56]="Serviço prestado"; 
$LANG['financial'][57]="Mês"; 
$LANG['financial'][59]="Horas de intervenções"; 
$LANG['financial'][60]="Na semana"; 
$LANG['financial'][61]="No Sábado"; 
$LANG['financial'][62]="Domingo e feriados"; 
$LANG['financial'][65]="Fornecedores associados"; 
$LANG['financial'][66]="Contratos Associados"; 
$LANG['financial'][68]="Activar as informações financeiras"; 
$LANG['financial'][69]="Periodicidade do Contracto"; 
$LANG['financial'][76]="Data de inicio"; 
$LANG['financial'][77]="Coeficiente de amortização"; 
$LANG['financial'][78]="Valor de termino da garantia"; 
$LANG['financial'][79]="Tipo de terceira pessoa"; 
$LANG['financial'][80]="Garantia a terminar"; 
$LANG['financial'][81]="Valor da conta de internet"; 
$LANG['financial'][82]="Numero da requisição"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="Para este tipo de elemento, informações financeiras são apenas um modelo para os elementos que irá adicionar."; 
$LANG['financial'][85]="Elemento requerido não encontrado"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Orçamento"; 
$LANG['financial'][88]="Expira em:"; 
$LANG['financial'][89]="TCO (value + tracking cost)"; 
$LANG['financial'][90]="Mensalmente TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Contractos expiram em menos de 30 dias"; 
$LANG['financial'][94]="Contractos que expiram daqui a 7 dias"; 
$LANG['financial'][95]="Contractos que expiram daqui a 30 dias"; 
$LANG['financial'][96]="Contractos que têm pré-aviso a começar em menos de 7 dias"; 
$LANG['financial'][97]="Contractos em que os pré-avisos começam em menos de 30 dias"; 
$LANG['financial'][98]="Data de fim"; 
$LANG['financial'][99]="Data de Expiração + Pré-Aviso"; 
$LANG['financial'][100]="Código Postal"; 
$LANG['financial'][101]="Cidade"; 
$LANG['financial'][102]="Estado"; 
$LANG['financial'][103]="País"; 
$LANG['financial'][104]="Artigos associados"; 
$LANG['financial'][105]="Tácito"; 
$LANG['financial'][106]="Expresso"; 
$LANG['financial'][107]="Renovação"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="hora(s)"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Muito Alto"; 
$LANG['help'][4]="Alto"; 
$LANG['help'][5]="Médio"; 
$LANG['help'][6]="Baixo"; 
$LANG['help'][7]="Muito Baixo"; 
$LANG['help'][8]="Informe sobre as acções tomadas"; 
$LANG['help'][11]="Meu E-mail"; 
$LANG['help'][14]="Submeter Mensagem"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Your message has been sent successfully, your request is on file."; 
$LANG['help'][19]="Thank you for using our automatic helpdesk system."; 
$LANG['help'][22]="Procurar o ID do seu computador"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Tipo de equipamento"; 
$LANG['help'][25]="Computador"; 
$LANG['help'][26]="Periférico de rede"; 
$LANG['help'][27]="Impressora"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Periférico"; 
$LANG['help'][30]="Geral"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Phone"; 
$LANG['help'][40]="Ticket sem título, tente de novo."; 
$LANG['help'][41]="Ticket sem categoria, tente de novo."; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="Instalar ou fazer update do GLPI"; 
$LANG['install'][1]="Choose 'Install' for a completely new installation of GLPI."; 
$LANG['install'][2]="Select 'Update' to update your version of GLPI from an earlier version"; 
$LANG['install'][3]="Instalar"; 
$LANG['install'][4]="Actualizar"; 
$LANG['install'][5]="A verificar a compatibilidade do seu ambiente para a execução do GLPI"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="Resultados"; 
$LANG['install'][8]="Teste de analisador PHP"; 
$LANG['install'][9]="You must install at least PHP5."; 
$LANG['install'][10]="GLPI is not compatible with the option zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP version is at least 5.x - Perfect !"; 
$LANG['install'][12]="Teste de sessões"; 
$LANG['install'][13]="O seu analisador de PHP não está compilado com suporte de sessões!"; 
$LANG['install'][14]="O suporte de sessões está disponível  - Perfeito !"; 
$LANG['install'][15]="Verifique que o suporte de sessões está activado no ficheiro de configuração php.ini"; 
$LANG['install'][16]="Verificação do modo de escrita para os ficheiros de backup"; 
$LANG['install'][17]="O arquivo não pode ser criado."; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="O ficheiro foi criado mas não pode ser eliminado."; 
$LANG['install'][20]="A file and a directory have be created and deleted - Perfect !"; 
$LANG['install'][21]="Verificação do modo de escrita para os documentos"; 
$LANG['install'][22]="Arquivo criado com sucesso!"; 
$LANG['install'][23]="Verificação do modo de escrita para os ficheiros de configuração"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Continuar ?"; 
$LANG['install'][26]="Continuar"; 
$LANG['install'][27]="Tentar novamente"; 
$LANG['install'][28]="Configuração de ligação da base de dados"; 
$LANG['install'][29]="Parâmetros de ligação á base de dados"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql user"; 
$LANG['install'][32]="Mysql password"; 
$LANG['install'][34]="Teste de ligação à base de dados"; 
$LANG['install'][35]="Impossível se conectar à base de dados"; 
$LANG['install'][36]="O servidor respondeu"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="Por favor seleccione a base de dados:"; 
$LANG['install'][39]="Create a new database or use an existing one:"; 
$LANG['install'][40]="Por favor seleccione a base de dados a actualizar:"; 
$LANG['install'][41]="Impossível usar a base de dados:"; 
$LANG['install'][43]="Sucesso - a base de dados foi inicialiada"; 
$LANG['install'][47]="Impossibilidade de escrever o ficheiro de configuração da base de dados"; 
$LANG['install'][48]="Erro ao criar a base de dados!"; 
$LANG['install'][49]="Você não seleccionou uma base de dados!"; 
$LANG['install'][50]="Verifique as permissões de escrita para os ficheiros  de sessão"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Teste de escrita dos ficheiros de log"; 
$LANG['install'][55]="A instalação foi finalizada"; 
$LANG['install'][57]="Default logins / passwords are:"; 
$LANG['install'][58]="glpi/glpi para conta de administração"; 
$LANG['install'][59]="tech/tech para conta de técnico"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Use GLPI"; 
$LANG['install'][65]="Teste da extensão magic_quotes_sybase"; 
$LANG['install'][66]="GLPI não pode funcionar com a opção magic_quotes_sybase ; Por favor desactive-a e tente de novo"; 
$LANG['install'][67]="A opção magic_quotes_sybase não está activa no seu servidor - Perfeito !"; 
$LANG['install'][68]="Test session auto start"; 
$LANG['install'][69]="session.auto_start is activated. See .htaccess file in the GLPI root for more information."; 
$LANG['install'][70]="Impossível criar o arquivo de conexão à base de dados, por favor verifique o arquivo de permissão."; 
$LANG['install'][71]="Teste de extensão Mysql."; 
$LANG['install'][72]="Precisa de compilar o mysql com a opção extensão Mysql."; 
$LANG['install'][73]="Ok - a função mysql_query() existe - Perfeito !"; 
$LANG['install'][74]="Teste se session_use_trans_sid é usado"; 
$LANG['install'][75]="Precisa de desactivar a opção Session_use_trans_id no seu php.ini"; 
$LANG['install'][76]="Ok - as sessões funcionam (sem problemas com trans_id) - Perfeito !"; 
$LANG['install'][77]="Passo"; 
$LANG['install'][81]="Início da instalação"; 
$LANG['install'][82]="Banco de dados criado"; 
$LANG['install'][85]="As funções foram encontradas - Perfeito!"; 
$LANG['install'][86]="Teste de alocação de memória"; 
$LANG['install'][87]="Memória alocada"; 
$LANG['install'][88]="A minimum of 64MB is commonly required for GLPI."; 
$LANG['install'][89]="Perfeito !"; 
$LANG['install'][90]="Tente aumentar o parametro memory_limit no ficheiro php.ini."; 
$LANG['install'][91]="Allocated memory > 64M"; 
$LANG['install'][92]="Licensa"; 
$LANG['install'][93]="Eu li e ACEITO os termos da licença descrita acima."; 
$LANG['install'][94]="Eu li e NÃO ACEITO os termos da licença descrita acima"; 
$LANG['install'][95]="Memória ilimitada"; 
$LANG['install'][96]="Memória ilimitada"; 
$LANG['install'][97]="Check permissions to the directory:"; 
$LANG['install'][99]="Verificar permissões de escrita nos ficheiros de cache"; 
$LANG['install'][100]="A pasta não pôde ser criada."; 
$LANG['install'][101]="A pasta foi criada mas não pôde ser removida."; 
$LANG['install'][102]="Test json functions"; 
$LANG['install'][103]="GLPI can't work correctly without the json_encode and json_decode functions"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="por"; 
$LANG['job'][4]="Requerente"; 
$LANG['job'][5]="Atribuida a"; 
$LANG['job'][6]="Técnico"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Describe the Problem/Action"; 
$LANG['job'][12]="Não existem actualizações para esta senha."; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Email de actualizações"; 
$LANG['job'][20]="Tempo total"; 
$LANG['job'][21]="Hora(s)"; 
$LANG['job'][22]="Minuto(s)"; 
$LANG['job'][29]="Adicionar nova actualização"; 
$LANG['job'][30]="Adicionar uma nova tarefa"; 
$LANG['job'][31]="Duração"; 
$LANG['job'][32]="Nenhum"; 
$LANG['job'][33]="Descrição vazia"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Planeamento"; 
$LANG['job'][37]="Sumário"; 
$LANG['job'][38]="Senha"; 
$LANG['job'][39]="Renovar a actualização"; 
$LANG['job'][40]="Custo de tempo"; 
$LANG['job'][41]="Custo fixo"; 
$LANG['job'][42]="Custo de material"; 
$LANG['job'][43]="Custo total"; 
$LANG['job'][44]="Fonte do pedido"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Estado"; 
$LANG['joblist'][1]="Apenas as minhas"; 
$LANG['joblist'][2]="Prioridade"; 
$LANG['joblist'][3]="Personal + group(s)"; 
$LANG['joblist'][4]="Atribuido"; 
$LANG['joblist'][6]="Descrição"; 
$LANG['joblist'][7]="Novo trabalho para este item..."; 
$LANG['joblist'][8]="Nenhum ticket encontrado."; 
$LANG['joblist'][9]="Novo"; 
$LANG['joblist'][10]="Fechado (resolvido)"; 
$LANG['joblist'][11]="Aberto sobre"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="No ticket in progress."; 
$LANG['joblist'][17]="Fechado (não resolvido)"; 
$LANG['joblist'][18]="A processar (atribuido)"; 
$LANG['joblist'][19]="A processar (planeado)"; 
$LANG['joblist'][21]="A processar"; 
$LANG['joblist'][26]="Aguardando"; 
$LANG['joblist'][27]="Email para manter rasto"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Não solucionado"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Selecione a categoria para este artigo:"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Editar este artigo"; 
$LANG['knowbase'][9]="Eliminar este artigo"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="Nome da categoria"; 
$LANG['knowbase'][14]="Assunto"; 
$LANG['knowbase'][15]="Índices"; 
$LANG['knowbase'][24]="Access to the Frequently Asked Questions"; 
$LANG['knowbase'][26]="Vistas"; 
$LANG['knowbase'][27]="Ligado"; 
$LANG['knowbase'][29]="Entradas Recentes"; 
$LANG['knowbase'][30]="Questões mais populares"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Sincronizar utilizadores já importados"; 
$LANG['ldap'][2]="Importar novos utilizadores"; 
$LANG['ldap'][3]="Não existem utilizadores a serem importados"; 
$LANG['ldap'][4]="Directório LDAP preferido"; 
$LANG['ldap'][5]="Por favor escolha o directório LDAP de onde pretende importar os utilizadores"; 
$LANG['ldap'][6]="Não é possível ligar ao directório LDAP"; 
$LANG['ldap'][7]="Não existe directório LDAP definido no GLPI"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Testar ligação para directório LDAP"; 
$LANG['ldap'][12]="Sincronização"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="no GLPI"; 
$LANG['ldap'][15]="Synchronize"; 
$LANG['ldap'][16]="Preconfiguration"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Replicate"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Main server"; 
$LANG['ldap'][22]="Replicate(s)"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Import of new groups"; 
$LANG['ldap'][25]="No group to be imported"; 
$LANG['ldap'][30]="How LDAP aliases should be handled"; 
$LANG['ldap'][31]="Never dereferenced (default)"; 
$LANG['ldap'][32]="Sempre referenciado"; 
$LANG['ldap'][33]="Dereferenced during the search (but not when locating)"; 
$LANG['ldap'][34]="Dereferenced when locating (not during the search)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Endereço"; 
$LANG['links'][4]="Tipo de equipamento associado"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Sem endereço definido"; 
$LANG['links'][9]="Conteúdo do ficheiro"; 

$LANG['log'][1]="sistema"; 
$LANG['log'][16]="planeamento"; 
$LANG['log'][18]="componentes"; 
$LANG['log'][20]="item adicionado"; 
$LANG['log'][21]="actualizar artigo"; 
$LANG['log'][22]="eliminar artigo"; 
$LANG['log'][23]="restaurar artigo"; 
$LANG['log'][24]="purgar artigo"; 
$LANG['log'][26]="desligar artigo"; 
$LANG['log'][27]="ligação do artigo"; 
$LANG['log'][28]="actualização dos componentes"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="associar um tipo"; 
$LANG['log'][31]="eliminar um tipo"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="eliminar endereço com artigo"; 
$LANG['log'][34]="incluir ligação com fornecedor"; 
$LANG['log'][35]="excluir associação com fornecedor"; 
$LANG['log'][40]="ligação IP"; 
$LANG['log'][41]="ligação falhada"; 
$LANG['log'][42]="Reservas"; 
$LANG['log'][44]="Cabecalho"; 
$LANG['log'][45]="Sucesso Total"; 
$LANG['log'][46]="Falhou"; 
$LANG['log'][48]="Adicionar utilizador ao grupo"; 
$LANG['log'][49]="eliminar um utilizador de um grupo"; 
$LANG['log'][55]="Ligação"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="Adicionar utilizador a uma entidade"; 
$LANG['log'][62]="Remover este utilizador definitivamente"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="regra"; 
$LANG['log'][66]="Segurança"; 
$LANG['log'][67]="modification of notes"; 
$LANG['log'][70]="porta de rede adicionada"; 
$LANG['log'][71]="add several network ports"; 
$LANG['log'][73]="porta de rede eliminada"; 
$LANG['log'][74]="deletion of several network ports"; 
$LANG['log'][75]="network port moved"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="adicionando versão"; 
$LANG['log'][83]="modification of version"; 
$LANG['log'][84]="version's deletion"; 
$LANG['log'][85]="adicionando licença"; 
$LANG['log'][86]="modification of licence"; 
$LANG['log'][87]="licence's deletion"; 
$LANG['log'][88]="adicionando cartuchos"; 
$LANG['log'][89]="adicionando consumiveis"; 
$LANG['log'][90]="Excluir cartucho"; 
$LANG['log'][91]="deletion of a consumable"; 
$LANG['log'][92]="restoration of a cartridge"; 
$LANG['log'][93]="restoration of a consumable"; 
$LANG['log'][94]="atualizar cartuchos"; 
$LANG['log'][95]="Instalação de cartuchos"; 
$LANG['log'][96]="Desinstalação dos cartuchos"; 
$LANG['log'][97]="material de consumo para o usuário"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Último acesso"; 
$LANG['login'][1]="Autentique-se novamente"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Acesso Negado"; 
$LANG['login'][6]="Utilizador"; 
$LANG['login'][7]="Senha"; 
$LANG['login'][8]="Utilizador ou senha vazia"; 
$LANG['login'][9]="Ainda não se encontra autenticado"; 
$LANG['login'][10]="Autenticação"; 
$LANG['login'][11]="Utilizador não autorizado a ligar-se ao GLPI"; 
$LANG['login'][12]="utilizador ou senha errado(a)"; 
$LANG['login'][13]="Campo da senha está vazio"; 
$LANG['login'][14]="utilizador desconhecido"; 
$LANG['login'][15]="Utilizador não encontrado ou vários utilizadores encontrados"; 
$LANG['login'][16]="falha na autenticação LDAP"; 
$LANG['login'][18]="Base interna GLPI"; 
$LANG['login'][20]="Não tem acesso a esta aplicação porque a sua conta foi desactivada ou removida"; 
$LANG['login'][21]="Teste de conectividade ao servidor IMAP/POP"; 
$LANG['login'][22]="Teste com sucesso"; 
$LANG['login'][23]="O teste falhou"; 
$LANG['login'][24]="Data do último acesso"; 
$LANG['login'][25]="Não tem direito de ligar-se"; 
$LANG['login'][26]="Precisa de activar a funcionalidade JavaScript no seu navegador"; 
$LANG['login'][27]="Deverá aceitar 'cookies' para aceder a esta aplicação"; 
$LANG['login'][30]="Alteração do método de autenticação"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Autenticação na base de dados GLPI"; 
$LANG['login'][33]="Autenticação no servidor IMAP/POP"; 

$LANG['mailgate'][0]="Mail Receiver"; 
$LANG['mailgate'][2]="Receber senhas de mail agora"; 
$LANG['mailgate'][3]="Número de correio electrónico disponível e retirado"; 
$LANG['mailgate'][4]="Não foi encontrada a extensão 'mbstring'. Cuidado com o código de caracteres usado (charset)."; 
$LANG['mailgate'][5]="Ficheiro anexado é inválido"; 
$LANG['mailgate'][6]="Ficheiro demasiado grande para anexar"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Descrição da senha"; 
$LANG['mailing'][10]="Novo desenvolvimento da senha"; 
$LANG['mailing'][12]="Senha atribuida a"; 
$LANG['mailing'][14]="Actualizar a categoria do ticket"; 
$LANG['mailing'][15]="Actualizar a prioridade do ticket"; 
$LANG['mailing'][17]="Actualizar o artigo do ticket"; 
$LANG['mailing'][18]="Update the author of the ticket"; 
$LANG['mailing'][19]="Nova reserva"; 
$LANG['mailing'][20]="Update the group of the ticket"; 
$LANG['mailing'][21]="Alteraçao na origem da senha"; 
$LANG['mailing'][23]="Modificação da reserva"; 
$LANG['mailing'][26]="Documento adicionado :"; 
$LANG['mailing'][27]="Actualizar o estado do ticket"; 
$LANG['mailing'][29]="Reserva cancelada"; 
$LANG['mailing'][30]="Senha actualizada"; 
$LANG['mailing'][31]="Isto é um mail de teste para verificar o funcionamento do sistema de correio electrónico."; 
$LANG['mailing'][32]="Teste de Mail"; 
$LANG['mailing'][33]="Alarme nos Cartuchos"; 
$LANG['mailing'][35]="Ponto inicial do alarme para o tipo de consumíveis alcançado:"; 
$LANG['mailing'][36]="Alarme nos Consumíveis"; 
$LANG['mailing'][37]="Contracto entrou em tempo de pré-aviso"; 
$LANG['mailing'][39]="Alarme dos Contractos"; 
$LANG['mailing'][40]="O artigo chegou no fim da garantia:"; 
$LANG['mailing'][41]="Alarme de Informações Financeiras"; 
$LANG['mailing'][42]="Alteração no custo das horas"; 
$LANG['mailing'][43]="Alteração nos custos fixos"; 
$LANG['mailing'][44]="Alteração no custo de material"; 
$LANG['mailing'][45]="Alteração no título da senha"; 
$LANG['mailing'][46]="Alteração na descrição da senha"; 
$LANG['mailing'][47]="Erro no envio do email"; 
$LANG['mailing'][48]="Alterar data de abertura"; 
$LANG['mailing'][49]="Alterar data de fechamento"; 
$LANG['mailing'][50]="Alterar dono do chamado"; 
$LANG['mailing'][51]="Licença expira a :"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Nenhuma categoria definida"; 
$LANG['mailing'][101]="Actualização por e-mail activada"; 
$LANG['mailing'][102]="Actualização por e-mail desactivada"; 
$LANG['mailing'][104]="Duração da actualização"; 
$LANG['mailing'][105]="Não atribuido"; 
$LANG['mailing'][107]="Nada"; 
$LANG['mailing'][109]="Sem grupo"; 
$LANG['mailing'][110]="Email inválido"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Computadores"; 
$LANG['Menu'][1]="Redes"; 
$LANG['Menu'][2]="Impressoras"; 
$LANG['Menu'][3]="Monitores"; 
$LANG['Menu'][4]="Programas"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Relatórios"; 
$LANG['Menu'][11]="Definições"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Estatísticas"; 
$LANG['Menu'][14]="Utilizadores"; 
$LANG['Menu'][15]="Administração"; 
$LANG['Menu'][16]="Periféricos"; 
$LANG['Menu'][17]="Reservas"; 
$LANG['Menu'][18]="Ferramentas"; 
$LANG['Menu'][19]="Base de Conhecimento"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Cartuchos"; 
$LANG['Menu'][22]="Contactos"; 
$LANG['Menu'][23]="Fornecedores"; 
$LANG['Menu'][24]="Informações Comerciais"; 
$LANG['Menu'][25]="Contratos"; 
$LANG['Menu'][26]="Gestão"; 
$LANG['Menu'][27]="Documentos"; 
$LANG['Menu'][28]="Estado"; 
$LANG['Menu'][29]="Planeamento"; 
$LANG['Menu'][30]="Logs"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Consumíveis"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefones"; 
$LANG['Menu'][35]="Perfis"; 
$LANG['Menu'][36]="Grupos"; 
$LANG['Menu'][37]="Entidades"; 
$LANG['Menu'][38]="Inventário"; 
$LANG['Menu'][39]="Receivers"; 
$LANG['Menu'][40]="Favoritos"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Microfone"; 
$LANG['monitors'][15]="Altifalantes"; 
$LANG['monitors'][18]="Flags"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Tamanho"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivô"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Porta de rede"; 
$LANG['networking'][13]="portas de rede encontradas"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Ligado a"; 
$LANG['networking'][19]="Adicionar portas de rede..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="activo"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="a porta"; 
$LANG['networking'][46]="Adicionar várias portas..."; 
$LANG['networking'][47]="De"; 
$LANG['networking'][48]="Para"; 
$LANG['networking'][51]="Network outlet"; 
$LANG['networking'][55]="Associar a VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Escolha o endereço MAC da lista ou especifique abaixo"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Máscara"; 
$LANG['networking'][61]="Subrede"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Opções de importação"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][10]="Importação global"; 
$LANG['ocsconfig'][11]="Sem importação"; 
$LANG['ocsconfig'][12]="Importação de unidade"; 
$LANG['ocsconfig'][13]="Importação de unidade: tudo é importado como está"; 
$LANG['ocsconfig'][14]="Importação global: tudo é importado mas o material é gerido globalmente (sem registos duplicados)"; 
$LANG['ocsconfig'][15]="Sem importação: o plugin não irá importar estes elementos"; 
$LANG['ocsconfig'][16]="Estado por omissão"; 
$LANG['ocsconfig'][17]="Limitar a importação dos seguintes identificadores (separador $, absolutamente nada)"; 
$LANG['ocsconfig'][18]="Check first that duplicates have been correctly managed in OCSNG"; 
$LANG['ocsconfig'][19]="Unit import on serial number"; 
$LANG['ocsconfig'][27]="General informations"; 
$LANG['ocsconfig'][36]="Modems"; 
$LANG['ocsconfig'][37]="Portas"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Registro"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Comportamento quando deconectando"; 
$LANG['ocsconfig'][49]="Lixo"; 
$LANG['ocsconfig'][50]="Remover"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="vazio"; 
$LANG['ocsconfig'][57]="igual"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Sincronização do computadores já importados"; 
$LANG['ocsng'][2]="Importação de novos computadores"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Ligar novos computadores OCS aos computadores GLPI existentes"; 
$LANG['ocsng'][5]="Importar novos computadores"; 
$LANG['ocsng'][6]="Actualização automática"; 
$LANG['ocsng'][7]="Importar de OCSNG"; 
$LANG['ocsng'][8]="Importação bem sucedida"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Actualizar os computadores"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Importar dados para GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Nenhum campo bloqueado"; 
$LANG['ocsng'][16]="Campos bloqueados"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Atenção! Os dados importados ( verifique a sua configuração) irá eliminar dados existentes"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Forçar sincronização"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Monitor(es) bloqueado(s)"; 
$LANG['ocsng'][32]="Dispositivos bloqueados"; 
$LANG['ocsng'][34]="Impressoras bloquedas"; 
$LANG['ocsng'][36]="Entidade de destino"; 
$LANG['ocsng'][37]="Ativar a visualização"; 
$LANG['ocsng'][38]="Desabilitar visualização prévia"; 
$LANG['ocsng'][40]="Match the rule ?"; 
$LANG['ocsng'][41]="Manual import mode"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="Identificador do OCS"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agente"; 
$LANG['ocsng'][50]="IP(s) bloqueado(s)"; 
$LANG['ocsng'][52]="Locked software(s)"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Volume(s) locked(s)"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="para"; 
$LANG['pager'][2]="de"; 
$LANG['pager'][3]="em"; 
$LANG['pager'][4]="Visualizar"; 
$LANG['pager'][5]="artigos"; 

$LANG['peripherals'][18]="Marca"; 
$LANG['peripherals'][31]="Gestão global"; 
$LANG['peripherals'][32]="Unidade de gestão"; 
$LANG['peripherals'][33]="Tipo de gestão"; 

$LANG['phones'][18]="Marca"; 
$LANG['phones'][36]="Fonte de alimentação"; 
$LANG['phones'][38]="Auscultadores"; 
$LANG['phones'][39]="Altifalantes"; 
$LANG['phones'][40]="Numero de linhas"; 

$LANG['planning'][0]="O técnico pretendido já se encontra com uma intervenção agendada para esse periodo."; 
$LANG['planning'][1]="Erro na introdução das datas. A data de inicio é seguramente posterior é data de término"; 
$LANG['planning'][5]="Dia"; 
$LANG['planning'][6]="Semana"; 
$LANG['planning'][8]="Manter rasto"; 
$LANG['planning'][9]="Por"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="Webcal:// Sincronização"; 
$LANG['planning'][14]="Mês"; 
$LANG['planning'][15]="O seu planeamento"; 
$LANG['planning'][16]="Informação"; 
$LANG['planning'][17]="Por fazer"; 
$LANG['planning'][18]="Feito"; 

$LANG['plugins'][0]="Plugins list"; 
$LANG['plugins'][2]="Installed / not configured"; 
$LANG['plugins'][3]="Installed / not activated"; 
$LANG['plugins'][4]="Erro ao limpar"; 
$LANG['plugins'][5]="Non-existent function(s)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Interface série"; 
$LANG['printers'][15]="Interface paralela"; 
$LANG['printers'][18]="Portas"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Contador de páginas inicial"; 
$LANG['printers'][31]="Página impressas"; 

$LANG['profiles'][0]="Direitos globais"; 
$LANG['profiles'][1]="Direitos da entidade"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Criar um ticket"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Show all tickets"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Ler"; 
$LANG['profiles'][11]="Escrever"; 
$LANG['profiles'][12]="Sem acesso"; 
$LANG['profiles'][13]="Perfil por omissão"; 
$LANG['profiles'][14]="Eliminar um ticket"; 
$LANG['profiles'][15]="Adicionar seguimentos a todos os tickets"; 
$LANG['profiles'][16]="To be in charge of a ticket"; 
$LANG['profiles'][17]="Ficar com um ticket"; 
$LANG['profiles'][18]="Update a ticket"; 
$LANG['profiles'][19]="Assign a ticket"; 
$LANG['profiles'][20]="View personnal planning"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Perfil"; 
$LANG['profiles'][23]="Administração das Reservas"; 
$LANG['profiles'][24]="Actualizar senha"; 
$LANG['profiles'][26]="Show tickets created by my groups"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Recursivo"; 
$LANG['profiles'][29]="Dinâmico"; 
$LANG['profiles'][30]="Visualizar informação OCSNG"; 
$LANG['profiles'][31]="Sincronizar OCSNG manual"; 
$LANG['profiles'][32]="See assigned tickets (personnal + group associated)"; 
$LANG['profiles'][33]="Utilizador não encontrado"; 
$LANG['profiles'][34]="Legenda"; 
$LANG['profiles'][35]="Update all followups"; 
$LANG['profiles'][36]="See schedule of people in my groups"; 
$LANG['profiles'][37]="Entidade por omissão"; 
$LANG['profiles'][38]="Visibilidade"; 
$LANG['profiles'][39]="Atribuição"; 
$LANG['profiles'][40]="Actualização"; 
$LANG['profiles'][41]="Criação"; 
$LANG['profiles'][42]="Associação"; 
$LANG['profiles'][43]="Método de autenticação e sincronização de utilizadores"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Caminho"; 
$LANG['registry'][3]="Chave/Valor"; 
$LANG['registry'][4]="Chaves de registo encontradas"; 
$LANG['registry'][5]="Nehuma chave da base de registo encontrada"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Notas pessoais"; 
$LANG['reminder'][1]="Notas públicas"; 
$LANG['reminder'][6]="Nova nota"; 
$LANG['reminder'][9]="Texto"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Sem Título"; 
$LANG['reminder'][16]="Notas Globais"; 

$LANG['reports'][0]="Seleccione o relatório que pretende gerar"; 
$LANG['reports'][4]="Lista de hardware sobre contracto"; 
$LANG['reports'][11]="Hardwares sobre contrato"; 
$LANG['reports'][12]="Tipo de hardware"; 
$LANG['reports'][13]="Data(s)"; 
$LANG['reports'][15]="Mostrar relatório"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Relatório padrão"; 
$LANG['reports'][27]="Por contrato"; 
$LANG['reports'][28]="Por ano"; 
$LANG['reports'][33]="Relatório de redes"; 
$LANG['reports'][36]="Dispositivos ligados"; 
$LANG['reports'][37]="Ponto de acesso"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Por localização"; 
$LANG['reports'][41]="By hardware"; 
$LANG['reports'][42]="Por ponto de acesso"; 
$LANG['reports'][46]="hardware ports"; 
$LANG['reports'][47]="portas do dispositico"; 
$LANG['reports'][49]="Network report by hardware"; 
$LANG['reports'][51]="Relatótio de rede por ponto de acesso"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Relatório de rede por localização"; 
$LANG['reports'][57]="Lista de Material"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Data de abertura"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Hardware Financial Information"; 
$LANG['reports'][63]="Outras informações financeiras (licenças, cartuchos, consumiveis)"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Artigos reserváveis"; 
$LANG['reservation'][2]="Dispositivo temporariamente indisponível"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Marcação"; 
$LANG['reservation'][9]="Marcação de um artigo"; 
$LANG['reservation'][16]="Para"; 
$LANG['reservation'][17]="De"; 
$LANG['reservation'][18]="O artigo requerido já se encontra reservado para o tempo pretendido"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Modificar o comentário"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Rehearsal"; 
$LANG['reservation'][28]="Por semana"; 
$LANG['reservation'][29]="Por dia"; 
$LANG['reservation'][30]="Número de vezes"; 
$LANG['reservation'][31]="por"; 
$LANG['reservation'][35]="Reservas futuras e em progresso"; 
$LANG['reservation'][36]="Reservas passadas"; 
$LANG['reservation'][37]="Nenhuma reserva"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="Isto removerá todas as reservas em progresso."; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="é"; 
$LANG['rulesengine'][1]="não é"; 
$LANG['rulesengine'][2]="contém"; 
$LANG['rulesengine'][3]="não contém"; 
$LANG['rulesengine'][4]="Iniciando com"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Critério"; 
$LANG['rulesengine'][7]="Acções"; 
$LANG['rulesengine'][8]="Gestão das regras"; 
$LANG['rulesengine'][9]="Logical operator"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Tipo de Acção"; 
$LANG['rulesengine'][12]="Campos"; 
$LANG['rulesengine'][13]="Valor"; 
$LANG['rulesengine'][14]="Condição"; 
$LANG['rulesengine'][15]="Razão"; 
$LANG['rulesengine'][16]="Critérios"; 
$LANG['rulesengine'][17]="Regras"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Regras e direitos da entidade"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Associar"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Tipo de regra"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Lista de regras"; 
$LANG['rulesengine'][30]="Acção"; 
$LANG['rulesengine'][33]="Lista do dicionário"; 
$LANG['rulesengine'][35]="Software dictionary"; 
$LANG['rulesengine'][36]="Manufacturer dictionary"; 
$LANG['rulesengine'][37]="Rules for assigning a category to software"; 
$LANG['rulesengine'][38]="Recalcular"; 
$LANG['rulesengine'][40]="A categoria"; 
$LANG['rulesengine'][41]="Validação"; 
$LANG['rulesengine'][42]="E"; 
$LANG['rulesengine'][43]="OU"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Cadastrar: Ip do equipamento"; 
$LANG['rulesengine'][47]="Cadastrar: Nome e dominio"; 
$LANG['rulesengine'][48]="Cadastrar equipamento"; 
$LANG['rulesengine'][49]="Cadastrar: endereço MAC do equipamento"; 
$LANG['rulesengine'][50]="Dicionário para modelos de computador"; 
$LANG['rulesengine'][51]="Monitor model dictionary"; 
$LANG['rulesengine'][52]="Phone model dictionary"; 
$LANG['rulesengine'][53]="Peripheral model dictionary"; 
$LANG['rulesengine'][54]="Printer model dictionary"; 
$LANG['rulesengine'][55]="Networking model dictionary"; 
$LANG['rulesengine'][56]="Modelos"; 
$LANG['rulesengine'][60]="Dicionário Tipo de Computador"; 
$LANG['rulesengine'][61]="Monitor type dictionary"; 
$LANG['rulesengine'][62]="Phone type dictionary"; 
$LANG['rulesengine'][63]="Peripheral type dictionary"; 
$LANG['rulesengine'][64]="Printer type dictionary"; 
$LANG['rulesengine'][65]="Networking device type dictionary"; 
$LANG['rulesengine'][66]="Tipos"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Dicionário Service Pack"; 
$LANG['rulesengine'][69]="OS versions dictionary"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Rename based on dictionary"; 
$LANG['rulesengine'][77]="Dicionários"; 
$LANG['rulesengine'][78]="Versão"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Dicionário Global"; 
$LANG['rulesengine'][81]="Resultado da regra"; 
$LANG['rulesengine'][82]="Detalhes dos resultados"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Test rules engine"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Software deleted by GLPI dictionary"; 
$LANG['rulesengine'][90]="Em progresso..."; 
$LANG['rulesengine'][91]="Work ended."; 
$LANG['rulesengine'][92]="Warning before running rename based on the dictionary"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSÃO"; 
$LANG['rulesengine'][95]="Manufacturer choice"; 
$LANG['rulesengine'][96]="Rename based on the manufacturer(s)dictionary<br> ( ----- = All)"; 
$LANG['rulesengine'][97]="No element to be tested"; 
$LANG['rulesengine'][100]="Informações da Cache"; 
$LANG['rulesengine'][102]="Nome da regra"; 
$LANG['rulesengine'][103]="Objectos em 'cache'"; 
$LANG['rulesengine'][104]="Valor original"; 
$LANG['rulesengine'][105]="Valor modificado"; 
$LANG['rulesengine'][106]="Unchanged"; 
$LANG['rulesengine'][107]="Inactivo"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Rights assignment"; 
$LANG['rulesengine'][111]="Atribuição de entidades"; 
$LANG['rulesengine'][112]="Rights and entities assignment"; 
$LANG['rulesengine'][120]="The engine stops on the first checked rule."; 
$LANG['rulesengine'][121]="The engine treats all the rules."; 
$LANG['rulesengine'][122]="The engine passes the result of a rule to the following ones."; 
$LANG['rulesengine'][130]="Entidade da LDAP"; 
$LANG['rulesengine'][131]="Entidade da TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Pesquisar por"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="contém"; 
$LANG['search'][4]="ordenado por"; 
$LANG['search'][8]="Data Inicial"; 
$LANG['search'][9]="Data Final"; 
$LANG['search'][10]="em"; 
$LANG['search'][11]="Artigos vistos"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Nenhum artigo encontrado"; 
$LANG['search'][16]="Pelo menos"; 
$LANG['search'][17]="Adicionar um critério de pesquisa"; 
$LANG['search'][18]="Eliminar um critério de pesquisa"; 
$LANG['search'][19]="Adicionar um critério global de pesquisa"; 
$LANG['search'][20]="Adicionar um critério global de pesquisa"; 

$LANG['setup'][0]="Menus de selecção"; 
$LANG['setup'][2]="Adicionar usuário"; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Tipos de Computador"; 
$LANG['setup'][5]="Sistemas Operativos"; 
$LANG['setup'][6]="Personalization"; 
$LANG['setup'][9]="Interface de rede"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Seleccione o idioma"; 
$LANG['setup'][42]="Tipos de rede"; 
$LANG['setup'][43]="Tipos de impressoras"; 
$LANG['setup'][44]="Tipos do monitores"; 
$LANG['setup'][45]="Tipo de caixas"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Seleccione a categoria a configurar"; 
$LANG['setup'][63]="Atenção está prestes a remover um cabeçalho usado em um ou mais artigos"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Pode substituir todos os eventos deste cabeçalho por outro:"; 
$LANG['setup'][67]="Autenticações externas"; 
$LANG['setup'][69]="Tipos de periféricos"; 
$LANG['setup'][70]="Configuração geral"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Ponto de rede"; 
$LANG['setup'][74]="Não pode eliminar esse local, porque contém sub-locais"; 
$LANG['setup'][75]="Como filho de"; 
$LANG['setup'][79]="Categoria dos tickets"; 
$LANG['setup'][80]="Tipos de terceiros"; 
$LANG['setup'][81]="Cabeçalhos dos documentos"; 
$LANG['setup'][82]="Tipo de contacto"; 
$LANG['setup'][83]="Estado do artigo"; 
$LANG['setup'][84]="Tipo de Cartucho"; 
$LANG['setup'][85]="Tipo de contrato"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Rede"; 
$LANG['setup'][89]="Dominio"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="Modelos de computadores"; 
$LANG['setup'][92]="Tipo de consumiveis"; 
$LANG['setup'][93]="Interfaces (Discos rígidos, ...)"; 
$LANG['setup'][94]="Modelos de monitores"; 
$LANG['setup'][95]="Modelos de rede"; 
$LANG['setup'][96]="Modelos de impressoras"; 
$LANG['setup'][97]="Modelos de periféricos"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Log Level"; 
$LANG['setup'][103]="1- Crítico (apenas erro de login)"; 
$LANG['setup'][104]="2- Alta Importância(não usado)"; 
$LANG['setup'][105]="3- Importante (logins com sucesso)"; 
$LANG['setup'][106]="4- Noticias (Adicionados, Excluídos, tracking)"; 
$LANG['setup'][107]="5- Completo (Tudo)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Show new tickets on the home page"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Linguagem por omissão"; 
$LANG['setup'][114]="Cores prioritárias"; 
$LANG['setup'][115]="Consumo por defeito para cartucho e número de consumíveis"; 
$LANG['setup'][116]="Atribuir automaticamente os tickets ao técnico responsável"; 
$LANG['setup'][117]="Autorizar a visualização das FAQ por utilizadores anónimos"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Adicionar automaticamente um utilizador de uma fonte de autenticação externa"; 
$LANG['setup'][125]="... De um fonte externa"; 
$LANG['setup'][126]="Adicionar automaticamente utilizador de fonte externa"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Formato da data"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Activar modo OCSNG"; 
$LANG['setup'][134]="Modo OCSNG"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Trandução"; 
$LANG['setup'][137]="Detecção de erros"; 
$LANG['setup'][138]="Usar no modo GLPI"; 
$LANG['setup'][139]="Comum"; 
$LANG['setup'][140]="Tipos"; 
$LANG['setup'][145]="Sistema Operativo"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Não para os horários"; 
$LANG['setup'][149]="Number of decimals in amounts"; 
$LANG['setup'][150]="Number Format"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (para ligações anonimas)"; 
$LANG['setup'][156]="Pass (para ligações não anónimas)"; 
$LANG['setup'][157]="O módulo LDAP do seu PHP não se está instalado"; 
$LANG['setup'][158]="Impossível usar LDAP como fonte externa de autenticação"; 
$LANG['setup'][159]="Filtro do ligção"; 
$LANG['setup'][162]="Configuração IMAP/POP"; 
$LANG['setup'][164]="IMAP/POP Host Name <br>(users email will be login@thishost)"; 
$LANG['setup'][165]="O seu PHP foi compilado sem as funções de IMAP"; 
$LANG['setup'][166]="Impossível utilizar IMAP/POP como fonte externa"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Opções de ligação"; 
$LANG['setup'][169]="Mail folder (optional, often INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Porta (opcional)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="Servidor CAS"; 
$LANG['setup'][175]="Porta"; 
$LANG['setup'][176]="Directório root (opcional)"; 
$LANG['setup'][177]="Configuração CAS"; 
$LANG['setup'][178]="O módulo CURL ou DOMXML do seu PHP não está instalado"; 
$LANG['setup'][179]="Impossivel utilizar CAS como fonte externa de autenticação"; 
$LANG['setup'][180]="Utilizar TLS"; 
$LANG['setup'][181]="Não existe a função ldap_start_tls"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Time zone"; 
$LANG['setup'][190]="Certificado x509"; 
$LANG['setup'][191]="Configurações de e-mail par x509"; 
$LANG['setup'][192]="Habilitar"; 
$LANG['setup'][193]="Field holding the login in the _SERVER array"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Keep status"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Copiar estado do PC"; 
$LANG['setup'][198]="Set status"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administrator Email"; 
$LANG['setup'][204]="Assinatura de email"; 
$LANG['setup'][205]="Mail enviado ao administrador"; 
$LANG['setup'][206]="Falha no envio de mail ao administrador"; 
$LANG['setup'][207]="E-mail para administrador (Se necessário)"; 
$LANG['setup'][217]="A funão de mail do PHP é desconhecida ou está desactivada no seu sistema"; 
$LANG['setup'][218]="O uso de SMTP é necessário"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Limite do calendário de planeamento"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Login Field"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Use a SMTP server to send emails"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP Password (optional)"; 
$LANG['setup'][236]="Anterior técnico responsável pelo ticket"; 
$LANG['setup'][237]="Administrador"; 
$LANG['setup'][239]="Técnico responsável pelo ticket"; 
$LANG['setup'][240]="Opções de Notificação"; 
$LANG['setup'][241]="Sem critérios pessoais. Por favor crie os seus parâmetros pessoais."; 
$LANG['setup'][242]="Opções de Alarme"; 
$LANG['setup'][243]="Alarmes nos consumíveis"; 
$LANG['setup'][244]="Alarmes nos cartunhos"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Alarmes nos contratos"; 
$LANG['setup'][247]="Alarmes nas informações financeiras"; 
$LANG['setup'][248]="Group in charge of the ticket"; 
$LANG['setup'][249]="Requester group"; 
$LANG['setup'][250]="Listas de campos de pesquisa predefinidos"; 
$LANG['setup'][252]="Seleccione artigos por omissão para visualizar"; 
$LANG['setup'][253]="Filtro para pesquisar nos grupos"; 
$LANG['setup'][254]="Tipo de pesquisa"; 
$LANG['setup'][255]="Atributo do grupo que contém os seus utilizadores"; 
$LANG['setup'][256]="Nos utilizadores"; 
$LANG['setup'][257]="Nos grupos"; 
$LANG['setup'][258]="Utilizadores & Grupos"; 
$LANG['setup'][259]="Pertencer aos grupos"; 
$LANG['setup'][260]="Atributo do utilizador que contém os seus grupos"; 
$LANG['setup'][261]="Grupo DN"; 
$LANG['setup'][262]="Use DN in the search"; 
$LANG['setup'][263]="Search filter for users"; 
$LANG['setup'][264]="Alarmes para licenças expiradas"; 
$LANG['setup'][271]="Restrict monitor management"; 
$LANG['setup'][272]="Restrict device management"; 
$LANG['setup'][273]="Restrict phone management"; 
$LANG['setup'][274]="for manual add"; 
$LANG['setup'][275]="Restrict printer management"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Cópia"; 
$LANG['setup'][284]="Apagar"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Verificar se existe uma nova versão disponível"; 
$LANG['setup'][301]="Nova versão disponível :"; 
$LANG['setup'][302]="You will find it on the GLPI-PROJECT.org site"; 
$LANG['setup'][303]="Está a usar a última versão disponível"; 
$LANG['setup'][304]="Connection failed. If you use a proxy, please configure it."; 
$LANG['setup'][305]="Todos os dias"; 
$LANG['setup'][306]="Verificar actualizações"; 
$LANG['setup'][307]="Nunca"; 
$LANG['setup'][308]="Todas as semanas"; 
$LANG['setup'][309]="Todos os meses"; 
$LANG['setup'][310]="Impossible to connect to site."; 
$LANG['setup'][311]="Failed to connect to the proxy server"; 
$LANG['setup'][312]="No data available on the web site"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Ligar com os artigos para a criação dos tickets"; 
$LANG['setup'][351]="Todos os artigos"; 
$LANG['setup'][352]="Linkable items to a ticket"; 
$LANG['setup'][360]="Campos automáticos (Marcosdos com *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Cabeçalho padrão para adição de documentos ao chamado"; 
$LANG['setup'][503]="Modelos de telefones"; 
$LANG['setup'][504]="Tipos de telefones"; 
$LANG['setup'][505]="Fontes de alimentação para tipos de telefone"; 
$LANG['setup'][601]="Valor LDAP"; 
$LANG['setup'][602]="Conexão ao banco do OCSNG"; 
$LANG['setup'][603]="Adicionar um utilizador"; 
$LANG['setup'][604]="Associar a um grupo"; 
$LANG['setup'][606]="Unable to add. The user already exists."; 
$LANG['setup'][607]="Associado ao perfil"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Título do chamado"; 
$LANG['setup'][611]="Índice dos chamados"; 
$LANG['setup'][612]="Categoria do chamado"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Link"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="Geral"; 
$LANG['setup'][704]="Notificações"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Mysql replicate"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Base de Dados"; 
$LANG['setup'][803]="Diferença entre pricipal e secundário"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Slave database out of sync!"; 
$LANG['setup'][809]="MySQL replica: read only"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Purchase version"; 
$LANG['software'][2]="Version in use"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Ilimitado"; 
$LANG['software'][5]="Versões"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Adicionar versão"; 
$LANG['software'][8]="Adicionar licença"; 
$LANG['software'][11]="Licenças"; 
$LANG['software'][17]="Software instalado"; 
$LANG['software'][19]="Instalado"; 
$LANG['software'][20]="Restante"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Actualização"; 
$LANG['software'][30]="Type of license"; 
$LANG['software'][32]="Data em que expira"; 
$LANG['software'][44]="Instalar um Software"; 
$LANG['software'][45]="Desinstalar um software"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Merging"; 
$LANG['software'][48]="Merge"; 
$LANG['software'][49]="Software deleted after merging"; 
$LANG['software'][50]="Associado ao computador"; 
$LANG['software'][51]="The number must be 1 to be able to affect"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Categoria do Software"; 

$LANG['state'][0]="Estado"; 
$LANG['state'][6]="Tipo de artigo"; 
$LANG['state'][7]="Nenhum artigo encontrado"; 
$LANG['state'][11]="Síntese"; 

$LANG['stats'][0]="Seleccionar estatísticas a serem visualizadas"; 
$LANG['stats'][1]="Global"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Por artigo"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Atraso médio na resolução de problemas"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Número de tickets resolvidos"; 
$LANG['stats'][13]="Número de tickets"; 
$LANG['stats'][15]="Duração média na resolução do problema"; 
$LANG['stats'][16]="Nome do técnico"; 
$LANG['stats'][20]="Utilizador"; 
$LANG['stats'][23]="Estatísticas indisponíveis"; 
$LANG['stats'][25]="Tempo médio real de um ticket"; 
$LANG['stats'][27]="Duração total real de um ticket"; 
$LANG['stats'][30]="Tempo médio de atraso a tomar em conta no ticket"; 
$LANG['stats'][31]="Dia(s)"; 
$LANG['stats'][33]="Minuto(s)"; 
$LANG['stats'][34]="Seg(s)"; 
$LANG['stats'][35]="Ticket(s)"; 
$LANG['stats'][44]="Nome do Fornecedor"; 
$LANG['stats'][45]="Por Hardware"; 
$LANG['stats'][47]="Por Tickets"; 
$LANG['stats'][48]="(atribuído)"; 
$LANG['stats'][49]="(seguimento)"; 

$LANG['title'][5]="Base de conhecimento"; 
$LANG['title'][6]="Redes"; 
$LANG['title'][9]="Estado do item"; 
$LANG['title'][10]="Seguimento dos tickets"; 
$LANG['title'][13]="Informações do utilizador"; 
$LANG['title'][14]="Fontes externas de autentificações"; 
$LANG['title'][24]="Assistência"; 
$LANG['title'][26]="Principal"; 
$LANG['title'][27]="Ligações"; 
$LANG['title'][28]="Tickets"; 
$LANG['title'][30]="Componentes"; 
$LANG['title'][33]="Ligações externas"; 
$LANG['title'][34]="Endereços"; 
$LANG['title'][37]="Notas"; 
$LANG['title'][38]="Historia"; 
$LANG['title'][40]="Notas pessoais e públicas"; 
$LANG['title'][42]="Alterações massivas"; 
$LANG['title'][43]="Registry"; 

$LANG['tracking'][1]="Meus dispositivos"; 
$LANG['tracking'][2]="Ou procura terminada"; 
$LANG['tracking'][3]="Datas inválidas. Atualização cancelada."; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="No description for your ticket, please retry."; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Documento do ticket"; 
$LANG['tracking'][29]="Número"; 
$LANG['tracking'][30]="Nova"; 
$LANG['tracking'][31]="A processar (atribuido)"; 
$LANG['tracking'][32]="A processar (planeado)"; 
$LANG['tracking'][34]="Directo"; 
$LANG['tracking'][35]="Escrito"; 
$LANG['tracking'][37]="Manter os tickets ao remover hardware no inventário"; 
$LANG['tracking'][38]="Foi enviado um email a"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Transferir"; 
$LANG['transfer'][3]="If no longer in use"; 
$LANG['transfer'][4]="Para limpar a lista de elementos a serem transferidos"; 
$LANG['transfer'][5]="Você pode continuar a adicionar elementos a serem transferidos ou executar a transferência agora"; 
$LANG['transfer'][6]="Faça um backup antes de transferir itens."; 
$LANG['transfer'][7]="Itens a transferir"; 
$LANG['transfer'][8]="Modo de transferência"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="Erro durante a actualização da base de dados"; 
$LANG['update'][91]="Cuidado !"; 
$LANG['update'][92]="Irá actualizar a base de dados GLPI de nome :"; 
$LANG['update'][93]="Ligação com base de dados feita com sucesso"; 
$LANG['update'][94]="Actualização efectuada, a sua base de dados encontra-se actualizada"; 
$LANG['update'][95]="A ligação com a base de dados falhou, verifique os parâmetros da ligação incluídos no ficheiro config_db.php"; 
$LANG['update'][96]="Agora, todos os administradores têm direitos de 'super-admin'. Este novo tipo de utilizador também foi adicionado."; 
$LANG['update'][105]="Impossível atingir a actualização desta forma!!"; 
$LANG['update'][106]="Voltar para o GLPI"; 
$LANG['update'][107]="Deverá agora proseguir com a actualização do conteudo da base de dados"; 
$LANG['update'][130]="Localizações actualizadas"; 
$LANG['update'][131]="A nova estrutura é hierárquica"; 
$LANG['update'][132]="Se usou um caracter de separação, poderá o definir para automatizar a geração da nova hierarquia."; 
$LANG['update'][133]="Poderia igualmente especificar uma localização base que irá incluir toda a plataforma gerada."; 
$LANG['update'][134]="Caractér de separação"; 
$LANG['update'][135]="Localização base"; 
$LANG['update'][136]="Esta é a nova hierarquia. Se estiver OK, poderá validar-la."; 
$LANG['update'][137]="Nova hierarquia"; 
$LANG['update'][138]="Localização actual"; 
$LANG['update'][139]="Otimizando tabelas"; 
$LANG['update'][140]="Criando índices"; 
$LANG['update'][141]="Mudança do layout do banco de dados"; 
$LANG['update'][142]="Migração de dados"; 

$LANG['users'][1]="Titulo"; 
$LANG['users'][2]="Categoria"; 

$LANG['validation'][0]="Aprovação"; 
$LANG['validation'][1]="Envie um pedido de Aprovação"; 
$LANG['validation'][2]="Situação"; 
$LANG['validation'][3]="Data do pedido"; 
$LANG['validation'][4]="Data da aprovação"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Comentário da aprovação"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Aguardando aprovação"; 
$LANG['validation'][10]="Recusado"; 
$LANG['validation'][11]="Aceito"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Tiquetes aguardando por sua aprovação"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Solicitante da Aprovação"; 
$LANG['validation'][19]="Aprovação concedida"; 
$LANG['validation'][20]="Aprovação negada"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="O usuário selecionado um endereço de e-mail válido. O pedido foi criado, sem confirmação de e-mail."; 
$LANG['validation'][26]="Pedido aprovado"; 
$LANG['validation'][27]="Um pedido de aprovação foi submetido"; 
$LANG['validation'][28]="Situação da requisição de aprovação"; 
$LANG['validation'][29]="Se a aprovação for negada, espefifique a razão"; 
$LANG['validation'][30]="Cancelar a solicitação de aprovação para"; 
$LANG['validation'][31]="Atualizar o pedido de Aprovação para"; 
$LANG['validation'][32]="Uma resposta para o pedido de Aprovação foi produzido"; 
$LANG['validation'][33]="Tiquetes aguardando aprovação"; 
?>